@@ -143,4 +143,66 @@ describe('hx-boost attribute', function() {
     this.server.respond()
     div.innerHTML.should.equal('Boosted!')
   })
+
+  it('form get with an unset action properly submits', function() {
+    this.server.respondWith('GET', /\/*/, function(xhr) {
+      xhr.respond(200, {}, 'Boosted!')
+    })
+
+    var div = make('<div hx-target="this" hx-boost="true"><form id="f1" method="get"><button id="b1">Submit</button></form></div>')
+    var btn = byId('b1')
+    btn.click()
+    this.server.respond()
+    div.innerHTML.should.equal('Boosted!')
+  })
+
+  it('form get with no action properly clears existing parameters on submit', function() {
+    /// add a foo=bar to the current url
+    var path = location.href
+    if (!path.includes('foo=bar')) {
+      if (!path.includes('?')) {
+        path += '?foo=bar'
+      } else {
+        path += '&foo=bar'
+      }
+    }
+    history.replaceState({ htmx: true }, '', path)
+
+    this.server.respondWith('GET', /\/*/, function(xhr) {
+      // foo should not be present because the form is a get with no action
+      should.equal(undefined, getParameters(xhr).foo)
+      xhr.respond(200, {}, 'Boosted!')
+    })
+
+    var div = make('<div hx-target="this" hx-boost="true"><form id="f1" method="get"><button id="b1">Submit</button></form></div>')
+    var btn = byId('b1')
+    btn.click()
+    this.server.respond()
+    div.innerHTML.should.equal('Boosted!')
+  })
+
+  it('form get with an empty action properly clears existing parameters on submit', function() {
+    /// add a foo=bar to the current url
+    var path = location.href
+    if (!path.includes('foo=bar')) {
+      if (!path.includes('?')) {
+        path += '?foo=bar'
+      } else {
+        path += '&foo=bar'
+      }
+    }
+    history.replaceState({ htmx: true }, '', path)
+
+    this.server.respondWith('GET', /\/*/, function(xhr) {
+      // foo should not be present because the form is a get with no action
+      should.equal(undefined, getParameters(xhr).foo)
+      xhr.respond(200, {}, 'Boosted!')
+    })
+
+    var div = make('<div hx-target="this" hx-boost="true"><form id="f1" action="" method="get"><button id="b1">Submit</button></form></div>')
+    var btn = byId('b1')
+    btn.click()
+    this.server.respond()
+    div.innerHTML.should.equal('Boosted!')
+  })
 })
