@@ -278,6 +278,16 @@ describe('Core htmx API test', function() {
     div.innerHTML.should.equal('foo!')
   })
 
+  // it('ajax api falls back to targeting body if target and source not set', function() {
+  //   this.server.respondWith('GET', '/test', 'foo!')
+  //   var div = make("<div id='d1'></div>")
+  //   const saveBody = document.body.innerHTML
+  //   htmx.ajax('GET', '/test', {})
+  //   this.server.respond()
+  //   document.body.innerHTML.should.equal('foo!')
+  //   document.body.innerHTML = saveBody
+  // })
+
   it('ajax api works with swapSpec', function() {
     this.server.respondWith('GET', '/test', "<p class='test'>foo!</p>")
     var div = make("<div><div id='target'></div></div>")
@@ -383,6 +393,17 @@ describe('Core htmx API test', function() {
     div.innerHTML.should.equal('delete')
   })
 
+  it('does not trigger load on re-init of an existing element', function() {
+    this.server.respondWith('GET', '/test', 'test')
+    var div = make('<div hx-get="/test" hx-trigger="load" hx-swap="beforeend"></div>')
+    this.server.respond()
+    div.innerHTML.should.equal('test')
+    div.setAttribute('hx-swap', 'afterbegin')
+    htmx.process(div)
+    this.server.respond()
+    div.innerHTML.should.equal('test')
+  })
+
   it('onLoad is called... onLoad', function() {
     // also tests on/off
     this.server.respondWith('GET', '/test', "<div id='d1' hx-get='/test'></div>")
